@@ -2,4 +2,4 @@ from .main_match import PipelineMatch, MatchInput
 from .func.function_image import PipelineImage
 from .func.function_text import PipelineText
 from .func.post_processing import PostProcessing
-from .pipeline.rerank import ReRank, ReRankConfig
+from .pipeline.rerank import ReRank
